{#-
# ozi/templates/tests/meson.build.j2
# SPDX-License-Identifier: MIT-0
-#}
{% for line in project.copyright_head.split('\n') %}{{ '# ' ~ line }}
{% endfor -%}
{{ '# DO NOT EDIT BY HAND - This file was generated for use with OZI tools.' }}
{{ '# ozi-fix -> meson rewrite is the standard editing pipeline.' }}
{% include 'project.meson.build' %}
