"""
This type stub file was generated by pyright.
"""

from __future__ import annotations

from pathlib import Path
from typing import TYPE_CHECKING, TypeAlias, TypeVar

from jinja2 import Environment

if TYPE_CHECKING:  # pragma: no cover
    from collections.abc import Mapping

    VT = TypeVar(
        'VT',
        str,
        int,
        float,
        bytes,
        None,
    )
    _Val: TypeAlias = list['_Key[VT]'] | Mapping['_Key[VT]', VT] | VT
    _Key: TypeAlias = VT | _Val[VT]

"""ozi-templates module"""
__all__ = ('load_environment', )
FILTERS = ...
def load_environment(
    project: dict[str, str | list[str]],
    _globals: dict[str, _Val[str]],
    target: Path | None = None
) -> Environment:
    """Load the rendering environment for templates.

    :param project: initial project namespace for rendering
    :param _globals: other globals for jinja2
    :param target: optional target folder for project template overrides
    :return: jinja2 rendering environment for OZI
    :rtype: Environment
    """
    ...

